@@ -68,7 +68,10 @@ class LupusecAPI:
         self._auth = None
         if self._username != None and self._password != None:
             self._auth = aiohttp.BasicAuth(login=self._username, password=self._password, encoding='utf-8')
+            _LOGGER.debug("...auth.encode: %s", self._auth.encode())  
+            _LOGGER.debug("...set aiohttp.BasicAuth")
         self._system = None
+        self._token = None
 
         # Try to access local cache file
         _LOGGER.debug(f"Check for Cache-File: {home}/{CONST.HISTORY_CACHE_NAME}")
@@ -100,10 +103,11 @@ class LupusecAPI:
         self._apiDevices = None
 
 
+    # ToDo: should renamed to: _async_api_get()
     async def _async_api_call(ip, client, action_url) -> Dict:
         """Generic sync method to call the Lupusec API"""
         # Generate complete URL from Constants.py
-        url = f'{CONST.URL_HTTP}{ip}{CONST.URL_ACTION}{action_url}'
+        url = f'{CONST.URL_HTTP}{ip}{CONST.URL_PORT}{CONST.URL_ACTION}{action_url}'
         _LOGGER.debug("_async_api_call() called: URL=%s", url)
         start_time = time.time()
         _LOGGER.debug(f"Starttime: {start_time}")
@@ -150,28 +154,28 @@ class LupusecAPI:
     async def _async_api_post(ip, client, action_url, params) -> Dict:
         """Generic sync method to call the Lupusec API"""
         # Generate complete URL from Constants.py
-        url = f'{CONST.URL_HTTP}{ip}{CONST.URL_ACTION}{action_url}'
+        url = f'{CONST.URL_HTTP}{ip}{CONST.URL_PORT}{CONST.URL_ACTION}{action_url}'
         _LOGGER.debug("_async_api_post() called: URL=%s", url)
         start_time = time.time()
         _LOGGER.debug(f"Starttime: {start_time}")
 
         try:
-            async with client.post(url, data=params) as resp:
-                _LOGGER.debug("Response_Status=%s", resp.status)
-                _LOGGER.debug("Content_Type=%s", resp.headers["content-type"])
-
+            async with client.post(url, data=params, ssl=False) as resp:
                 # check for Response Status other than 200
+                _LOGGER.debug("Response_Status=%s", resp.status)
                 if resp.status != 200:
                     _LOGGER.error(f"ERROR: Response status = {resp.status}")
                     return {}
 
                 # check for non-JSON Response Headers   
+                _LOGGER.debug("Content_Type=%s", resp.headers["content-type"])              
                 if not resp.headers["content-type"].strip().startswith("application/json"):
                     _LOGGER.error(f"ERROR: Content Type is not JSON = {resp.headers['content-type']}")
+                    content = await resp.text()
+                    print(content)
                     return {}
 
                 # Get Response Body
-                # content = await resp.json()
                 content = await resp.text()
 
                 # ToDo: check for empty body, size = 0
@@ -194,6 +198,32 @@ class LupusecAPI:
             return {}
 
 
+
+    async def async_get_token(self, client) -> int:
+        """Async method to get the a session token from Lupusec System."""
+        _LOGGER.debug("__init__.py.async_get_token() called: ")
+
+         # Get Session Token
+        async with LupusecAPI._async_api_call(self._ip_address, client, CONST.TOKEN_REQUEST) as response:
+            # Print response list
+            _LOGGER.debug("await response...")
+            response_list = await response
+            _LOGGER.debug("done. check content in response_list...")
+            for content in response_list:
+                print(content)
+                _LOGGER.debug("response.getsizeof(): %s", sys.getsizeof(content)) 
+                if (sys.getsizeof(content) > 0):
+                    _LOGGER.debug("RESULT_RESPONSE: %s", content[CONST.RESPONSE_RESULT]) 
+                    if (content[CONST.RESPONSE_RESULT] == 1):
+                        _LOGGER.debug("RESPONSE_MESSAGE: %s", content[CONST.RESPONSE_MESSAGE]) 
+                        if (len(content[CONST.RESPONSE_MESSAGE]) != 0):
+                            self._token = content[CONST.RESPONSE_MESSAGE]
+                            _LOGGER.debug("Token: %s", self._token)    
+                            return content[CONST.RESPONSE_RESULT]
+                    return 0
+                return 0
+        _LOGGER.debug("__init__.py.async_get_token() finished.")  
+
     async def async_get_system(self) -> None:
         """Async method to get the system info."""
         _LOGGER.debug("__init__.py.async_get_system() called: ")
@@ -226,25 +256,40 @@ class LupusecAPI:
     async def async_set_mode(self, mode) -> None:
         """Async method to set alarm mode."""
         _LOGGER.debug("__init__.py.async_set_mode() called: ")
-        _LOGGER.info("...mode: ", str(mode))
+        _LOGGER.info("...set mode: %s", mode)
 
         params = {"mode": mode, "area": 1}
 
          # Set Alarm Mode
         async with aiohttp.ClientSession(auth=self._auth) as client:
+            _LOGGER.debug("auth.encode: %s", self._auth.encode())            
             tasks = []
 
-            # INFO_REQUEST
-            _LOGGER.debug("__init__.py.async_set_mode(): REQUEST=%s", CONST.SET_ALARM_REQUEST)
-            tasks.append(asyncio.ensure_future(LupusecAPI._async_api_post(self._ip_address, client, 
-                CONST.SET_ALARM_REQUEST, params)))
-
-            # Print response list
+            # Get Session Token
+            _LOGGER.debug("__init__.py.async_set_mode(): REQUEST=%s", CONST.TOKEN_REQUEST)
+            tasks.append(asyncio.ensure_future(LupusecAPI.async_get_token(self, client)))
             _LOGGER.debug("await asyncio.gather(*tasks)...")
             response_list = await asyncio.gather(*tasks)
             _LOGGER.debug("done. check content in response_list...")
             for content in response_list:
-                print(content)              
+                print(content)
+                if (content != 0):
+                    _LOGGER.debug("Token: %s", self._token)
+                    # SET_ALARM_REQUEST
+                    _LOGGER.debug("__init__.py.async_set_mode(): REQUEST=%s", CONST.SET_ALARM_REQUEST)
+                    tasks.append(asyncio.ensure_future(LupusecAPI._async_api_post(self._ip_address, client, 
+                        CONST.SET_ALARM_REQUEST, params)))
+
+                    # Print response list
+                    _LOGGER.debug("await asyncio.gather(*tasks)...")
+                    response_list = await asyncio.gather(*tasks)
+                    _LOGGER.debug("done. check content in response_list...")
+                    for content in response_list:
+                        print(content)  
+
+                else :    
+                    _LOGGER.debug("ERROR: no session Token available.")
+            
         _LOGGER.debug("__init__.py.async_set_mode() finished.")
 
 
