@@ -4,7 +4,7 @@
 # -*- coding: utf-8 -*-
 
 # Project Information
-VERSION = "0.3.36"
+VERSION = "0.3.51"
 PROJECT_PACKAGE_NAME = "lupulib"
 PROJECT_LICENSE = "MIT"
 PROJECT_URL = "http://www.github.com/majuss/lupulib"
@@ -21,12 +21,16 @@ PROJECT_AUTHOR = "piehler73"
 
 # Lupusec API Calls: Requests and Headers
 URL_HTTP = "https://"
+URL_PORT = ":443"
 URL_ACTION = "/action/"
 UPDATE_FREQ = 2
+RESPONSE_RESULT = "result"
+RESPONSE_MESSAGE = "message"
 
 LOGIN_REQUEST = "login"
 INFO_REQUEST = "welcomeGet"
 INFO_HEADER = "updates"
+TOKEN_REQUEST = "tokenGet"
 SET_ALARM_REQUEST = "panelCondPost"
 DEVICE_LIST_REQUEST = "deviceListGet"
 DEVICE_LIST_HEADER = "senrows"
